Class PythonParser.Builder

java.lang.Object
org.openrewrite.Parser.Builder
org.openrewrite.python.PythonParser.Builder
All Implemented Interfaces:
Cloneable
Enclosing class:
PythonParser

public static class PythonParser.Builder extends org.openrewrite.Parser.Builder
  • Constructor Details

    • Builder

      public Builder()
  • Method Details

    • maxSizeBytes

      public PythonParser.Builder maxSizeBytes(long maxSizeBytes)
      Set the maximum file size (in bytes) for files to be parsed as Python. Files exceeding this size will be parsed as plain text to avoid performance issues.
      Parameters:
      maxSizeBytes - The maximum size of a file in bytes that will be parsed as Python.
      Returns:
      This builder.
    • build

      public PythonParser build()
      Specified by:
      build in class org.openrewrite.Parser.Builder
    • getDslName

      public String getDslName()
      Specified by:
      getDslName in class org.openrewrite.Parser.Builder