Package org.openrewrite.python.internal
@NullMarked
@NonNullFields
package org.openrewrite.python.internal
-
ClassesClassDescriptionRegenerates a lock file by running
<packageManager> lockin a temporary directory seeded with the dependencies file (and optionally an existing lock).Locates and runs a Python package manager CLI.Parses Pipfile.lock files (JSON format) to extract resolved dependency information.Shared utilities for Python dependency recipes operating on pyproject.toml files.Extracts dependency metadata from a parsed pyproject.toml AST (Toml.Document).Overlays resolved-dependency information from a parsed lock file onto aPythonResolutionResultmarker.Parses uv.lock files (TOML format) to extract resolved dependency information.