Enum Class Quoted.Style

java.lang.Object
java.lang.Enum<Quoted.Style>
org.openrewrite.python.marker.Quoted.Style
All Implemented Interfaces:
Serializable, Comparable<Quoted.Style>, Constable
Enclosing class:
Quoted

public static enum Quoted.Style extends Enum<Quoted.Style>
  • Enum Constant Details

    • SINGLE

      public static final Quoted.Style SINGLE
    • DOUBLE

      public static final Quoted.Style DOUBLE
    • TRIPLE_SINGLE

      public static final Quoted.Style TRIPLE_SINGLE
    • TRIPLE_DOUBLE

      public static final Quoted.Style TRIPLE_DOUBLE
    • BACKTICK

      public static final Quoted.Style BACKTICK
      Backtick quoting used for repr() in Python 2: `x`
  • Method Details

    • values

      public static Quoted.Style[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static Quoted.Style valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null