Package org.openrewrite.python
@NullMarked
@NonNullFields
package org.openrewrite.python
-
ClassesClassDescriptionAdd a dependency to a Python project.Change a dependency to a different package.Manages workspace directories for Python projects with dependencies.Parser for Pipfile files that delegates to
TomlParserand attaches aPythonResolutionResultmarker with dependency metadata.Parser for pyproject.toml files that delegates to TomlParser and attaches aPythonResolutionResultmarker with dependency metadata.Parser for Python source files.Remove a dependency from a Python project.Parser for requirements.txt files that delegates toPlainTextParserand attaches aPythonResolutionResultmarker with dependency metadata resolved viauv pip freeze.Parser for setup.cfg files that delegates toPlainTextParserand attaches aPythonResolutionResultmarker with dependency metadata resolved viauv pip install <projectDir>anduv pip freeze.Upgrade the version constraint for a dependency.Pin a transitive dependency version using the strategy appropriate for the file type and package manager.