Class ParseProjectOptions

java.lang.Object
org.openrewrite.python.rpc.ParseProjectOptions

public class ParseProjectOptions extends Object
Optional inputs to PythonRewriteRpc.parseProject(Path, ParseProjectOptions, org.openrewrite.ExecutionContext).

Bundles the optional, independent parsing inputs into one value so the API doesn't grow a long tail of positional parameters (and adjacent same-typed arguments that are easy to transpose). Build with

invalid reference
#builder()
; every field is optional and defaults to null.
  • Constructor Details

    • ParseProjectOptions

      public ParseProjectOptions()