Class DependencyInsight

java.lang.Object
org.openrewrite.Recipe
org.openrewrite.python.search.DependencyInsight
All Implemented Interfaces:
Cloneable

public class DependencyInsight extends org.openrewrite.Recipe
Find direct and transitive Python dependencies matching a package name pattern. Searches pyproject.toml and requirements.txt files that have a PythonResolutionResult marker attached. Search result markers are placed on dependency string literals in pyproject.toml, or on the PlainText source file for requirements.txt.
  • Nested Class Summary

    Nested classes/interfaces inherited from class org.openrewrite.Recipe

    org.openrewrite.Recipe.Builder, org.openrewrite.Recipe.DelegatingRecipe
  • Field Summary

    Fields inherited from class org.openrewrite.Recipe

    contributors, examples, PANIC
  • Constructor Summary

    Constructors
    Constructor
    Description
     
  • Method Summary

    Modifier and Type
    Method
    Description
     
    org.openrewrite.TreeVisitor<?,org.openrewrite.ExecutionContext>
     
    org.openrewrite.Validated<Object>
     

    Methods inherited from class org.openrewrite.Recipe

    addDataTable, builder, buildRecipeList, causesAnotherCycle, clone, createRecipeDescriptor, equals, getContributors, getDataTableDescriptors, getDescription, getDescriptor, getDisplayName, getEstimatedEffortPerOccurrence, getExamples, getInstanceName, getJacksonPolymorphicTypeTag, getMaintainers, getName, getRecipeList, getTags, hashCode, maxCycles, noop, onComplete, run, run, run, setContributors, setExamples, validate, validateAll, validateAll, withOptions

    Methods inherited from class java.lang.Object

    finalize, getClass, notify, notifyAll, toString, wait, wait, wait
  • Constructor Details

    • DependencyInsight

      public DependencyInsight()
  • Method Details

    • getInstanceNameSuffix

      public String getInstanceNameSuffix()
      Overrides:
      getInstanceNameSuffix in class org.openrewrite.Recipe
    • validate

      public org.openrewrite.Validated<Object> validate()
      Overrides:
      validate in class org.openrewrite.Recipe
    • getVisitor

      public org.openrewrite.TreeVisitor<?,org.openrewrite.ExecutionContext> getVisitor()
      Overrides:
      getVisitor in class org.openrewrite.Recipe