All Classes and Interfaces
Class
Description
Add a dependency to a Python project.
Change a dependency to a different package.
Find direct and transitive Python dependencies matching a package name pattern.
Manages workspace directories for Python projects with dependencies.
Marker indicating that a
J.MethodInvocation represents a Python 2 exec statement
rather than a Python 3 exec function call.Marks a method argument like
**kwargs
as a holder of a dictionary of arguments.Trait implementation for Pipfile dependency files.
Parser for Pipfile files that delegates to
TomlParser and attaches a
PythonResolutionResult marker with dependency metadata.Marker indicating that a
J.MethodInvocation represents a Python 2 print statement
rather than a Python 3 print function call.Shared utilities for Python dependency recipes operating on pyproject.toml files.
Parser for pyproject.toml files that delegates to TomlParser and attaches a
PythonResolutionResult marker with dependency metadata.Typed view over
ExecutionContext for shared state used by
Python dependency management recipes.Trait for Python dependency files (pyproject.toml, requirements.txt, etc.).
Extracts dependency metadata from a parsed pyproject.toml AST (Toml.Document).
Parser for Python source files.
A receiver for Python AST elements that uses the Java RPC framework.
Contains metadata about a Python project, parsed from pyproject.toml and uv.lock.
A dependency specification parsed from a PEP 508 string in pyproject.toml.
A resolved (locked) dependency from uv.lock.
A sender for Python AST elements that uses the Java RPC framework.
Ideally, we'll reuse AutoFormatVisitor from Java, but Python requires specific handling of whitespace
to maintain column alignment.
Python-specific codec for TrailingComma that uses PythonReceiver.visitSpace
to properly handle PyComment in the suffix.
Validates that the contents of lists and containers like JLeftPadded respect their generic types.
Used for `J.Identifier` nodes that are quoted in the source.
Remove a dependency from a Python project.
Parser for requirements.txt files that delegates to
PlainTextParser and attaches a
PythonResolutionResult marker with dependency metadata resolved via uv pip freeze.Parser for setup.cfg files that delegates to
PlainTextParser and attaches a
PythonResolutionResult marker with dependency metadata resolved via
uv pip install <projectDir> and uv pip freeze.Upgrade the version constraint for a dependency.
Pin a transitive dependency version using the strategy appropriate for the file type
and package manager.
Shared utility for finding and executing the uv Python package manager.
Parses uv.lock files (TOML format) to extract resolved dependency information.
Utility for regenerating uv.lock files by running
uv lock in a temporary directory.