All Classes and Interfaces
Class
Description
Marks a method argument like
**kwargs
as a holder of a dictionary of arguments.Parser for Python source files.
A receiver for Python AST elements that uses the Java RPC framework.
A sender for Python AST elements that uses the Java RPC framework.
Ideally, we'll reuse AutoFormatVisitor from Java, but Python requires specific handling of whitespace
to maintain column alignment.
Python-specific codec for TrailingComma that uses PythonReceiver.visitSpace
to properly handle PyComment in the suffix.
Validates that the contents of lists and containers like JLeftPadded respect their generic types.
Used for `J.Identifier` nodes that are quoted in the source.