All Classes and Interfaces

Class
Description
 
 
Marks a method argument like **kwargs as a holder of a dictionary of arguments.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
Ideally, we'll reuse AutoFormatVisitor from Java, but Python requires specific handling of whitespace to maintain column alignment.
 
Used for `J.Identifier` nodes that are quoted in the source.