All Classes and Interfaces

Class
Description
 
 
 
 
GroupedStatement.StatementGroup<T extends org.openrewrite.java.tree.Statement>
 
In some contexts, the Python `None` literal is optional and can be inferred from empty expressions.
 
In Python, many operators are actually syntax sugar for method calls.
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
For use as a last resort when Python elements semantically fit into the `J` scheme, but lack the fields to store the necessary padding.
 
 
 
 
 
 
 
Ideally, we'll reuse AutoFormatVisitor from Java, but Python requires specific handling of whitespace to maintain column alignment.