All Classes and Interfaces
Class
Description
See `python-plugin/README.md`.
GroupedStatement.StatementGroup<T extends org.openrewrite.java.tree.Statement>
In some contexts, the Python `None` literal is optional and can be inferred from empty expressions.
In Python, many operators are actually syntax sugar for method calls.
For use as a last resort when Python elements semantically fit into the `J` scheme,
but lack the fields to store the necessary padding.
Visit K types.