Package org.openrewrite.python
Class PythonParser
java.lang.Object
org.openrewrite.python.PythonParser
- All Implemented Interfaces:
org.openrewrite.Parser
Parser for Python source files.
This parser uses RPC to communicate with a Python process that performs the actual parsing. The Python process uses the Python AST module to parse source code and converts it to the OpenRewrite LST format.
-
Nested Class Summary
Nested ClassesNested classes/interfaces inherited from interface org.openrewrite.Parser
org.openrewrite.Parser.Input -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanstatic PythonParser.Builderbuilder()Stream<org.openrewrite.SourceFile> parseInputs(Iterable<org.openrewrite.Parser.Input> sources, @Nullable Path relativeTo, org.openrewrite.ExecutionContext ctx) sourcePathFromSourceText(Path prefix, String sourceCode) Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface org.openrewrite.Parser
accept, acceptedInputs, getCharset, parse, parse, parse, requirePrintEqualsInput, reset
-
Constructor Details
-
PythonParser
public PythonParser()
-
-
Method Details
-
parseInputs
public Stream<org.openrewrite.SourceFile> parseInputs(Iterable<org.openrewrite.Parser.Input> sources, @Nullable Path relativeTo, org.openrewrite.ExecutionContext ctx) - Specified by:
parseInputsin interfaceorg.openrewrite.Parser
-
accept
- Specified by:
acceptin interfaceorg.openrewrite.Parser
-
sourcePathFromSourceText
- Specified by:
sourcePathFromSourceTextin interfaceorg.openrewrite.Parser
-
builder
-