Package org.openrewrite.python
Class PythonParser.Builder
java.lang.Object
org.openrewrite.Parser.Builder
org.openrewrite.python.PythonParser.Builder
- All Implemented Interfaces:
Cloneable
- Enclosing class:
PythonParser
public static class PythonParser.Builder
extends org.openrewrite.Parser.Builder
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbuild()maxSizeBytes(long maxSizeBytes) Set the maximum file size (in bytes) for files to be parsed as Python.Methods inherited from class org.openrewrite.Parser.Builder
clone, getSourceFileType
-
Constructor Details
-
Builder
public Builder()
-
-
Method Details
-
maxSizeBytes
Set the maximum file size (in bytes) for files to be parsed as Python. Files exceeding this size will be parsed as plain text to avoid performance issues.- Parameters:
maxSizeBytes- The maximum size of a file in bytes that will be parsed as Python.- Returns:
- This builder.
-
build
- Specified by:
buildin classorg.openrewrite.Parser.Builder
-
getDslName
- Specified by:
getDslNamein classorg.openrewrite.Parser.Builder
-