Package org.openrewrite.python
Enum Class PythonParser.PythonLanguageLevel
java.lang.Object
java.lang.Enum<PythonParser.PythonLanguageLevel>
org.openrewrite.python.PythonParser.PythonLanguageLevel
- All Implemented Interfaces:
Serializable,Comparable<PythonParser.PythonLanguageLevel>,Constable
- Enclosing class:
PythonParser
Python language version selectable on the parser.
Only the levels the parser actually branches on are exposed: the Py2.7
grammar (via the parso-based path) is distinct from the Py3 grammar
(via the ast module). New minor versions are added as the
parser starts to distinguish them.
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum Constants -
Method Summary
Modifier and TypeMethodDescriptionReturns the enum constant of this class with the specified name.static PythonParser.PythonLanguageLevel[]values()Returns an array containing the constants of this enum class, in the order they are declared.version()
-
Enum Constant Details
-
PYTHON_2_7
-
PYTHON_3
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
version
- Returns:
- The version string sent over the RPC parse request to select the corresponding parser path on the server.
-