Package org.openrewrite.python.internal
Class PythonDependencyExecutionContextView
java.lang.Object
org.openrewrite.DelegatingExecutionContext
org.openrewrite.python.internal.PythonDependencyExecutionContextView
- All Implemented Interfaces:
org.openrewrite.ExecutionContext,org.openrewrite.rpc.RpcCodec<org.openrewrite.ExecutionContext>
public class PythonDependencyExecutionContextView
extends org.openrewrite.DelegatingExecutionContext
Typed view over
ExecutionContext for shared state used by
Python dependency management recipes.
Lock file state is shared across all recipes in the same execution so that sequential recipes in a composite correctly build on each other's lock regeneration results.
-
Field Summary
Fields inherited from interface org.openrewrite.ExecutionContext
CURRENT_CYCLE, CURRENT_RECIPE, REQUIRE_PRINT_EQUALS_INPUT, RUN_TIMEOUT, SCANNING_MUTATION_VALIDATION -
Method Summary
Modifier and TypeMethodDescriptionExisting uv.lock contents keyed by pyproject.toml source path.Regenerated uv.lock contents keyed by pyproject.toml source path.view(org.openrewrite.ExecutionContext ctx) Methods inherited from class org.openrewrite.DelegatingExecutionContext
getDelegate, getMessage, getMessages, getOnError, getOnTimeout, pollMessage, putMessageMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface org.openrewrite.ExecutionContext
addObserver, computeMessage, computeMessageIfAbsent, getCycle, getCycleDetails, getMessage, getObservers, pollMessage, putCurrentRecipe, putMessageInCollection, putMessageInSet, rpcReceive, rpcSend
-
Method Details
-
view
-
getUpdatedLockFiles
Regenerated uv.lock contents keyed by pyproject.toml source path. Updated by recipe visitors after lock regeneration so that subsequent recipes seed with the latest lock content. -
getExistingLockContents
Existing uv.lock contents keyed by pyproject.toml source path. Populated during the scanning phase from on-disk lock files and updated after each lock regeneration so that the next recipe seeds with the latest lock content.
-