Package org.openrewrite.python.internal
@NullMarked
@NonNullFields
package org.openrewrite.python.internal
-
ClassesClassDescriptionShared utilities for Python dependency recipes operating on pyproject.toml files.Extracts dependency metadata from a parsed pyproject.toml AST (Toml.Document).Shared utility for finding and executing the uv Python package manager.Parses uv.lock files (TOML format) to extract resolved dependency information.Utility for regenerating uv.lock files by running
uv lockin a temporary directory.