Package org.openrewrite.python
@NullMarked
@NonNullFields
package org.openrewrite.python
-
ClassesClassDescriptionAdd a dependency to the
[project].dependenciesarray in pyproject.toml.Change a dependency to a different package in pyproject.toml.Manages workspace directories for Python projects with dependencies.Parser for pyproject.toml files that delegates to TomlParser and attaches aPythonResolutionResultmarker with dependency metadata.Parser for Python source files.Remove a dependency from the[project].dependenciesarray in pyproject.toml.Parser for requirements.txt files that delegates toPlainTextParserand attaches aPythonResolutionResultmarker with dependency metadata resolved viauv pip freeze.Parser for setup.cfg files that delegates toPlainTextParserand attaches aPythonResolutionResultmarker with dependency metadata resolved viauv pip install <projectDir>anduv pip freeze.Upgrade the version constraint for a dependency in[project].dependenciesin pyproject.toml.Pin a transitive dependency version by adding or upgrading a constraint in the appropriate tool-specific section.