Package org.openrewrite.python
@NullMarked
@NonNullFields
package org.openrewrite.python
-
ClassesClassDescriptionAdd a dependency to the
[project].dependenciesarray in pyproject.toml.Change a dependency to a different package in pyproject.toml.Parser for pyproject.toml files that delegates to TomlParser and attaches aPythonResolutionResultmarker with dependency metadata.Parser for Python source files.Remove a dependency from the[project].dependenciesarray in pyproject.toml.Upgrade the version constraint for a dependency in[project].dependenciesin pyproject.toml.Pin a transitive dependency version by adding or upgrading a constraint in the appropriate tool-specific section.