Package org.openrewrite.python.rpc
Class ParseProjectOptions
java.lang.Object
org.openrewrite.python.rpc.ParseProjectOptions
Optional inputs to
PythonRewriteRpc.parseProject(Path, ParseProjectOptions, org.openrewrite.ExecutionContext).
Bundles the optional, independent parsing inputs into one value so the API doesn't grow a long
tail of positional parameters (and adjacent same-typed arguments that are easy to transpose). Build
with
; every field is optional and defaults to invalid reference
#builder()null.
-
Constructor Summary
Constructors -
Method Summary
-
Constructor Details
-
ParseProjectOptions
public ParseProjectOptions()
-