Package org.openrewrite.python.rpc
Class PythonRewriteRpc.Builder
java.lang.Object
org.openrewrite.python.rpc.PythonRewriteRpc.Builder
- All Implemented Interfaces:
Supplier<PythonRewriteRpc>
- Enclosing class:
PythonRewriteRpc
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionSet the port for Python debugger to listen on.environment(Map<String, String> environment) get()marketplace(org.openrewrite.marketplace.RecipeMarketplace marketplace) metricsCsv(@Nullable Path metricsCsv) pythonPath(Path pythonPath) Path to the Python executable.traceRpcMessages(boolean verboseLogging) workingDirectory(@Nullable Path workingDirectory) Set the working directory for the Python process.
-
Constructor Details
-
Builder
public Builder()
-
-
Method Details
-
marketplace
public PythonRewriteRpc.Builder marketplace(org.openrewrite.marketplace.RecipeMarketplace marketplace) -
pythonPath
Path to the Python executable.- Parameters:
pythonPath- The path to the Python executable (e.g., "python3", "/usr/bin/python3")- Returns:
- This builder
-
timeout
-
log
-
metricsCsv
-
environment
-
traceRpcMessages
-
traceRpcMessages
-
debugPort
Set the port for Python debugger to listen on.- Parameters:
rewriteSourcePath- The path to the Python Rewrite source codedebugPort- The port for the debugger to listen on- Returns:
- This builder
-
workingDirectory
Set the working directory for the Python process.- Parameters:
workingDirectory- The working directory for the Python process- Returns:
- This builder
-
get
- Specified by:
getin interfaceSupplier<PythonRewriteRpc>
-