Package org.openrewrite.python.search
Class DependencyInsight
java.lang.Object
org.openrewrite.Recipe
org.openrewrite.python.search.DependencyInsight
- All Implemented Interfaces:
Cloneable
public class DependencyInsight
extends org.openrewrite.Recipe
Find direct and transitive Python dependencies matching a package name pattern.
Searches pyproject.toml and requirements.txt files that have a
PythonResolutionResult marker attached.
Search result markers are placed on dependency string literals in pyproject.toml, or on the
PlainText source file for requirements.txt.-
Nested Class Summary
Nested classes/interfaces inherited from class org.openrewrite.Recipe
org.openrewrite.Recipe.Builder, org.openrewrite.Recipe.DelegatingRecipe -
Field Summary
Fields inherited from class org.openrewrite.Recipe
contributors, examples, PANIC -
Constructor Summary
Constructors -
Method Summary
Methods inherited from class org.openrewrite.Recipe
addDataTable, builder, buildRecipeList, causesAnotherCycle, clone, createRecipeDescriptor, equals, getContributors, getDataTableDescriptors, getDescription, getDescriptor, getDisplayName, getEstimatedEffortPerOccurrence, getExamples, getInstanceName, getJacksonPolymorphicTypeTag, getMaintainers, getName, getRecipeList, getTags, hashCode, maxCycles, noop, onComplete, run, run, run, setContributors, setExamples, validate, validateAll, validateAll, withOptions
-
Constructor Details
-
DependencyInsight
public DependencyInsight()
-
-
Method Details
-
getInstanceNameSuffix
- Overrides:
getInstanceNameSuffixin classorg.openrewrite.Recipe
-
validate
- Overrides:
validatein classorg.openrewrite.Recipe
-
getVisitor
public org.openrewrite.TreeVisitor<?,org.openrewrite.ExecutionContext> getVisitor()- Overrides:
getVisitorin classorg.openrewrite.Recipe
-