Package org.openrewrite.python.search
@NullMarked
@NonNullFields
package org.openrewrite.python.search
-
ClassesClassDescriptionFind direct and transitive Python dependencies matching a package name pattern.Match Python source files that import a given module, by the as-written import syntax rather than by type attribution.